@@ -78,7 +78,7 @@ int main(int argc, FAR char *argv[])
 
   /* Connect the socket to the server */
 
-  addrlen = strlen(CONFIG_EXAMPLES_USTREAM_ADDR) + 1;
+  addrlen = sizeof(CONFIG_EXAMPLES_USTREAM_ADDR);
   if (addrlen > UNIX_PATH_MAX)
     {
       addrlen = UNIX_PATH_MAX;
