@@ -157,7 +157,8 @@ static int nxcamera_cmd_stream(FAR struct nxcamera_s *pcam, FAR char *parg)
       0
     };
 
-  sscanf(parg, "%hd %hd %d %4s", &width, &height, &framerate, cc);
+  sscanf(parg, "%"SCNu16" %"SCNu16" %"SCNu32" %4s",
+                &width, &height, &framerate, cc);
   format = v4l2_fourcc(cc[0], cc[1], cc[2], cc[3]);
 
   /* Try to stream raw data with settings specified */
