@@ -1,4 +1,4 @@
-/************************************************************************************
+/****************************************************************************
  * apps/system/termcurses/tcurses_vt100.c
  *
  * Licensed to the Apache Software Foundation (ASF) under one or more
@@ -16,11 +16,11 @@
  * License for the specific language governing permissions and limitations
  * under the License.
  *
- ************************************************************************************/
+ ****************************************************************************/
 
-/************************************************************************************
+/****************************************************************************
  * Included Files
- ************************************************************************************/
+ ****************************************************************************/
 
 #include <nuttx/config.h>
 
@@ -44,9 +44,9 @@
 #include <sys/ioctl.h>
 #include <nuttx/kmalloc.h>
 
-/************************************************************************************
+/****************************************************************************
  * Pre-processor Definitions
- ************************************************************************************/
+ ****************************************************************************/
 
 #define KEY_DOWN        0x102  /* Down arrow key */
 #define KEY_UP          0x103  /* Up arrow key */
@@ -61,9 +61,9 @@
 #define TINFO_ENTRY(n, d, c)  d, c
 #endif
 
-/************************************************************************************
+/****************************************************************************
  * Private Types
- ************************************************************************************/
+ ****************************************************************************/
 
 struct tcurses_vt100_s
 {
@@ -78,14 +78,15 @@ struct tcurses_vt100_s
   tcflag_t lflag;
 };
 
-/************************************************************************************
+/****************************************************************************
  * Private Function Prototypes
- ************************************************************************************/
+ ****************************************************************************/
 
-static FAR struct termcurses_s *tcurses_vt100_initialize(int in_fd, int out_fd);
+static FAR struct termcurses_s *tcurses_vt100_initialize(int in_fd,
+                                                         int out_fd);
 static int tcurses_vt100_clear(FAR struct termcurses_s *dev, int type);
-static int tcurses_vt100_move(FAR struct termcurses_s *dev, int type, int col,
-              int row);
+static int tcurses_vt100_move(FAR struct termcurses_s *dev, int type,
+                              int col, int row);
 static int tcurses_vt100_getwinsize(FAR struct termcurses_s *dev,
               FAR struct winsize *winsz);
 static int tcurses_vt100_setcolors(FAR struct termcurses_s *dev,
@@ -97,9 +98,9 @@ static int tcurses_vt100_getkeycode(FAR struct termcurses_s *dev,
 static bool tcurses_vt100_checkkey(FAR struct termcurses_s *dev);
 static int tcurses_vt100_terminate(FAR struct termcurses_s *dev);
 
-/************************************************************************************
+/****************************************************************************
  * Private Data
- ************************************************************************************/
+ ****************************************************************************/
 
 static const struct termcurses_ops_s g_vt100_ops =
 {
@@ -713,9 +714,9 @@ static const struct keycodes_s g_ctrl_keycodes[] =
 };
 #endif /* CONFIG_SYSTEM_TERMCURSES_VT100_OSX_ALT_CODES */
 
-/************************************************************************************
+/****************************************************************************
  * Public Data
- ************************************************************************************/
+ ****************************************************************************/
 
 struct termcurses_dev_s g_vt100_tcurs =
 {
@@ -724,13 +725,13 @@ struct termcurses_dev_s g_vt100_tcurs =
   "vt100, vt102, ansi"           /* List of supported terminals */
 };
 
-/************************************************************************************
+/****************************************************************************
  * Private Functions
- ************************************************************************************/
+ ****************************************************************************/
 
-/************************************************************************************
+/****************************************************************************
  * Clear screen / line operations
- ************************************************************************************/
+ ****************************************************************************/
 
 static int tcurses_vt100_clear(FAR struct termcurses_s *dev, int type)
 {
@@ -774,9 +775,9 @@ static int tcurses_vt100_clear(FAR struct termcurses_s *dev, int type)
   return ret;
 }
 
-/************************************************************************************
+/****************************************************************************
  * Move cursor operations
- ************************************************************************************/
+ ****************************************************************************/
 
 static int tcurses_vt100_move(FAR struct termcurses_s *dev, int type,
                               int col, int row)
@@ -812,9 +813,9 @@ static int tcurses_vt100_move(FAR struct termcurses_s *dev, int type,
   return ret;
 }
 
-/************************************************************************************
+/****************************************************************************
  * Calculates an ANSI 256 color index based on the 24-bit RGB value given.
- ************************************************************************************/
+ ****************************************************************************/
 
 static uint8_t tcurses_vt100_getcolorindex(int red, int green, int blue)
 {
@@ -898,9 +899,9 @@ static uint8_t tcurses_vt100_getcolorindex(int red, int green, int blue)
   return 16 + r * 36 + g * 6 + b;
 }
 
-/************************************************************************************
+/****************************************************************************
  * Set fg / bg colors
- ************************************************************************************/
+ ****************************************************************************/
 
 static int tcurses_vt100_setcolors(FAR struct termcurses_s *dev,
                                    FAR struct termcurses_colors_s *colors)
@@ -917,9 +918,9 @@ static int tcurses_vt100_setcolors(FAR struct termcurses_s *dev,
 
   if ((colors->color_mask & TCURS_COLOR_FG) != 0)
     {
-      sprintf(str, g_setfgcolor,
-              tcurses_vt100_getcolorindex(colors->fg_red, colors->fg_green,
-                                          colors->fg_blue));
+      snprintf(str, sizeof(str), g_setfgcolor,
+               tcurses_vt100_getcolorindex(colors->fg_red, colors->fg_green,
+                                           colors->fg_blue));
       ret = write(fd, str, strlen(str));
     }
 
@@ -927,14 +928,15 @@ static int tcurses_vt100_setcolors(FAR struct termcurses_s *dev,
 
   if ((colors->color_mask & TCURS_COLOR_BG) != 0)
     {
-      if (colors->bg_red != 0 || colors->bg_green != 0 || colors->bg_blue != 0)
+      if (colors->bg_red != 0 || colors->bg_green != 0 ||
+          colors->bg_blue != 0)
         {
           colors->bg_red = 0;
         }
 
-      sprintf(str, g_setbgcolor,
-              tcurses_vt100_getcolorindex(colors->bg_red, colors->bg_green,
-                                          colors->bg_blue));
+      snprintf(str, sizeof(str), g_setbgcolor,
+               tcurses_vt100_getcolorindex(colors->bg_red, colors->bg_green,
+                                           colors->bg_blue));
       ret = write(fd, str, strlen(str));
     }
 
@@ -948,9 +950,9 @@ static int tcurses_vt100_setcolors(FAR struct termcurses_s *dev,
   return ret;
 }
 
-/************************************************************************************
+/****************************************************************************
  * Get windows size from terminal emulator connected to serial port
- ************************************************************************************/
+ ****************************************************************************/
 
 static int tcurses_vt100_getwinsize(FAR struct termcurses_s *dev,
                                     FAR struct winsize *winsz)
@@ -1045,9 +1047,9 @@ static int tcurses_vt100_getwinsize(FAR struct termcurses_s *dev,
   return -ENOSYS;
 }
 
-/************************************************************************************
+/****************************************************************************
  * Set display attributes
- ************************************************************************************/
+ ****************************************************************************/
 
 static int tcurses_vt100_setattributes(FAR struct termcurses_s *dev,
                                        unsigned long attrib)
@@ -1091,23 +1093,23 @@ static int tcurses_vt100_setattributes(FAR struct termcurses_s *dev,
 
   if (attrib & TCURS_ATTRIB_BLINK)
     {
-      strcat(str, g_setblink);
+      strlcat(str, g_setblink, sizeof(str));
     }
   else
     {
-      strcat(str, g_setnoblink);
+      strlcat(str, g_setnoblink, sizeof(str));
     }
 
   if (attrib & TCURS_ATTRIB_UNDERLINE)
     {
-      strcat(str, g_setunderline);
+      strlcat(str, g_setunderline, sizeof(str));
     }
   else
     {
-      strcat(str, g_setnounderline);
+      strlcat(str, g_setnounderline, sizeof(str));
     }
 
-  strcat(str, "m");
+  strlcat(str, "m", sizeof(str));
 
   ret = write(fd, str, strlen(str));
 
@@ -1118,11 +1120,11 @@ static int tcurses_vt100_setattributes(FAR struct termcurses_s *dev,
   return ret;
 }
 
-/************************************************************************************
+/****************************************************************************
  * Get keycode from the terminal, translating special escape sequences into
  * special key values.
  *
- ************************************************************************************/
+ ****************************************************************************/
 
 static int tcurses_vt100_getkeycode(FAR struct termcurses_s *dev,
                                     FAR int *specialkey,
@@ -1168,7 +1170,9 @@ static int tcurses_vt100_getkeycode(FAR struct termcurses_s *dev,
   tv.tv_sec     = 0;
   tv.tv_usec    = 1000;
 
-  /* Loop until we have a valid key code, taking escape sequences into account */
+  /* Loop until we have a valid key code, taking escape sequences
+   * into account
+   */
 
   keycode       = -1;
   *keymodifiers = 0;
@@ -1237,7 +1241,7 @@ static int tcurses_vt100_getkeycode(FAR struct termcurses_s *dev,
                   continue;
                 }
 
-              /* No more characters waiting in the queue.  Must be ESC key.  */
+              /* No more characters waiting in the queue.  Must be ESC key. */
 
               return '\x1b';
             }
@@ -1409,10 +1413,10 @@ static int tcurses_vt100_getkeycode(FAR struct termcurses_s *dev,
   return keycode;
 }
 
-/************************************************************************************
+/****************************************************************************
  * Check if a key is cached for processing.
  *
- ************************************************************************************/
+ ****************************************************************************/
 
 static bool tcurses_vt100_checkkey(FAR struct termcurses_s *dev)
 {
@@ -1451,18 +1455,19 @@ static bool tcurses_vt100_checkkey(FAR struct termcurses_s *dev)
   return false;
 }
 
-/************************************************************************************
+/****************************************************************************
  * Public Functions
- ************************************************************************************/
+ ****************************************************************************/
 
-/************************************************************************************
+/****************************************************************************
  * Name: tcurses_vt100_initialize
  *
  * Description:
- *   Initialize a specific instance of the VT100 TermCurses handler and bind it to
- *   a specific file descriptor pair (input/output ... typically stdin / stdout).
+ *   Initialize a specific instance of the VT100 TermCurses handler and
+ *   bind it to a specific file descriptor pair
+ *   (input/output ... typically stdin / stdout).
  *
- ************************************************************************************/
+ ****************************************************************************/
 
 FAR struct termcurses_s *tcurses_vt100_initialize(int in_fd, int out_fd)
 {
@@ -1471,7 +1476,8 @@ FAR struct termcurses_s *tcurses_vt100_initialize(int in_fd, int out_fd)
 
   /* Allocate a new device structure */
 
-  priv = (FAR struct tcurses_vt100_s *)zalloc(sizeof(struct tcurses_vt100_s));
+  priv =
+    (FAR struct tcurses_vt100_s *)zalloc(sizeof(struct tcurses_vt100_s));
   if (priv == NULL)
     {
       return NULL;
@@ -1515,13 +1521,13 @@ FAR struct termcurses_s *tcurses_vt100_initialize(int in_fd, int out_fd)
   return (FAR struct termcurses_s *)priv;
 }
 
-/************************************************************************************
+/****************************************************************************
  * Name: tcurses_vt100_terminate
  *
  * Description:
  *   Terminates a specific instance of the VT100 TermCurses handler.
  *
- ************************************************************************************/
+ ****************************************************************************/
 
 static int tcurses_vt100_terminate(FAR struct termcurses_s *dev)
 {
