@@ -25,6 +25,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <sys/ioctl.h>
+#include <sys/param.h>
 #include <crypto/cryptodev.h>
 #include <crypto/md5.h>
 #include <crypto/sha1.h>
@@ -192,7 +193,7 @@ int main(void)
 {
   char output[32];
   int ret = 0;
-  for (int i = 0; i < sizeof(testcase) / sizeof(struct tb); i++)
+  for (int i = 0; i < nitems(testcase); i++)
     {
       ret += syshmac(CRYPTO_MD5_HMAC, testcase[i].key,
                      testcase[i].keylen,
@@ -215,7 +216,7 @@ int main(void)
         }
     }
 
-  for (int i = 0; i < sizeof(testcase) / sizeof(struct tb); i++)
+  for (int i = 0; i < nitems(testcase); i++)
     {
       ret = syshmac(CRYPTO_SHA1_HMAC, testcase[i].key,
                     testcase[i].keylen,
@@ -238,7 +239,7 @@ int main(void)
         }
     }
 
-  for (int i = 0; i < sizeof(testcase) / sizeof(struct tb); i++)
+  for (int i = 0; i < nitems(testcase); i++)
     {
       ret = syshmac(CRYPTO_SHA2_256_HMAC, testcase[i].key,
                     testcase[i].keylen,
