@@ -61,6 +61,7 @@
 #include <nuttx/config.h>
 
 #include <sys/types.h>
+#include <sys/param.h>
 #include <stdint.h>
 #include <stdbool.h>
 
@@ -78,8 +79,6 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#define ARRAYSIZE(a) (sizeof (a) / sizeof (a)[0])
-
 /****************************************************************************
  * Private Types
  ****************************************************************************/
@@ -1152,7 +1151,7 @@ int main(int argc, FAR char *argv[])
              "assignments...\n",
              i ? 'f' : 's');
 
-      for (t = 0; t < ARRAYSIZE(test_data); ++t)
+      for (t = 0; t < nitems(test_data); ++t)
         {
           /* Prefill the arguments with zeroes. */
 
@@ -1329,7 +1328,7 @@ int main(int argc, FAR char *argv[])
   /* Test the char, short, and long specification-modifiers. */
 
   printf("\nTesting scanf()'s type-modifiers...\n");
-  for (t = 0; t < ARRAYSIZE(type_data); ++t)
+  for (t = 0; t < nitems(type_data); ++t)
     {
       unsigned char hhu;
       unsigned short hu;
